/*
 * This file is automatically generated.  DON'T EDIT THIS FILE MANUALLY.
 */

#include "sombok_constants.h"
#include "sombok.h"
#define UNICODE_VERSION "6.1.0"
const char *linebreak_unicode_version = UNICODE_VERSION;

const char *linebreak_propvals_EA[] = {
    "Z", "Na", "N", "A", "W", "H", "F", "ZA", "ZW", NULL
};
const char *linebreak_propvals_GB[] = {
    "CR", "LF", "Control", "Extend", "Prepend", "SpacingMark", "L", "V", 
    "T", "LV", "LVT", "Other", "Virama", "OtherLetter", NULL
};
const char *linebreak_propvals_LB[] = {
    "BK", "CR", "LF", "NL", "SP", "OP", "CL", "QU", "GL", "NS", "EX", "SY", 
    "IS", "PR", "PO", "NU", "AL", "ID", "IN", "HY", "BA", "BB", "B2", "CB", 
    "ZW", "CM", "WJ", "H2", "H3", "JL", "JV", "JT", "CP", "SG", "AI", "SA", 
    "HL", "CJ", "XX", NULL
};
const char *linebreak_propvals_SC[] = {
    "Common", "Inherited", "Unknown", "Han", "Hangul", "Thai", "Lao", 
    "Myanmar", "Khmer", "Tai_Le", "New_Tai_Lue", "Tai_Tham", "Tai_Viet", 
    NULL
};

#define M (LINEBREAK_ACTION_MANDATORY)
#define D (LINEBREAK_ACTION_DIRECT)
#define I (LINEBREAK_ACTION_INDIRECT)
#define P (LINEBREAK_ACTION_PROHIBITED)
#define r(cc) static propval_t rule_##cc[]
/* Note: Entries related to BK, CR, CM, LF, NL aren't used by break(). */
    /* BkCrLfNlSpOpClQuGlNsExSyIsPrPoNuAlIdInHyBaBbB2CbZwCmWjH2H3JlJvJtCp */
r(BK)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(CR)={M,M,P,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(LF)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(NL)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(SP)={P,P,P,P,P,D,P,D,D,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P};
r(OP)={P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P};
r(CL)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(QU)={P,P,P,P,P,P,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(GL)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(NS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(EX)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(SY)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(IS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(PR)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,I,D,I,I,D,D,D,P,D,P,I,I,I,I,I,P};
r(PO)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(NU)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,D,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(AL)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,I,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(ID)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(IN)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(HY)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(BA)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(BB)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,D,P,I,P,I,I,I,I,I,P};
r(B2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,P,D,P,D,P,D,D,D,D,D,P};
r(CB)={P,P,P,P,P,D,P,I,I,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P};
r(ZW)={P,P,P,P,P,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,P,D,D,D,D,D,D,D,D};
r(CM)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(WJ)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(H2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P};
r(H3)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P};
r(JL)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,I,I,I,I,D,P};
r(JV)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P};
r(JT)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P};
r(CP)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,I,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
#undef r
propval_t *linebreak_rules[] = {
    rule_BK, rule_CR, rule_LF, rule_NL, rule_SP, rule_OP, rule_CL, rule_QU, 
    rule_GL, rule_NS, rule_EX, rule_SY, rule_IS, rule_PR, rule_PO, rule_NU, 
    rule_AL, rule_ID, rule_IN, rule_HY, rule_BA, rule_BB, rule_B2, rule_CB, 
    rule_ZW, rule_CM, rule_WJ, rule_H2, rule_H3, rule_JL, rule_JV, rule_JT, 
    rule_CP
};

size_t linebreak_rulessiz = 33;

unsigned short linebreak_prop_index[] = {
    0, 32, 64, 94, 125, 157, 189, 219, 248, 276, 307, 333, 345, 345, 363,
    345, 345, 345, 392, 343, 345, 345, 420, 345, 452, 452, 469, 498, 529,
    559, 589, 345, 620, 636, 652, 345, 681, 345, 345, 345, 345, 345, 345,
    345, 704, 721, 753, 774, 806, 345, 838, 870, 345, 345, 887, 918, 944,
    962, 983, 345, 345, 1009, 1041, 1062, 1088, 1116, 1130, 345, 345, 345,
    345, 1158, 1190, 1196, 1227, 1257, 1288, 1292, 1323, 1353, 1384, 1388,
    1419, 1445, 1384, 1388, 1477, 1507, 1288, 1525, 1557, 1587, 1617, 1620,
    1652, 1678, 1709, 1713, 1744, 1587, 1774, 1778, 1810, 1587, 1774, 1620,
    1842, 1872, 1774, 345, 1898, 1930, 1961, 1976, 2008, 345, 2039, 2071,
    2103, 345, 2135, 2167, 345, 2199, 2231, 2256, 2288, 345, 2320, 2339,
    2371, 2402, 2432, 345, 345, 345, 2464, 2464, 2464, 2496, 2496, 2525,
    2533, 2539, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2571, 2603,
    345, 345, 345, 345, 2604, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2636, 345, 345, 2665,
    2679, 2700, 2723, 2723, 2755, 2767, 2797, 1041, 2827, 345, 345, 345, 345,
    1610, 345, 345, 345, 2859, 2887, 2905, 2937, 2957, 2984, 345, 3016, 3048,
    3059, 3091, 3123, 3155, 345, 345, 3187, 3199, 3229, 3260, 3292, 3323,
    345, 3349, 345, 3377, 3123, 3409, 345, 345, 3441, 3472, 345, 345, 345,
    345, 345, 345, 3504, 987, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 3536, 3568, 3600, 3631, 3663, 3695, 3727,
    962, 3519, 3756, 3787, 3800, 3832, 3858, 3884, 3910, 3935, 3967, 3998,
    4028, 4060, 4090, 4117, 345, 345, 4130, 4153, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 4185, 4185, 4185, 4185, 4207, 4185, 4185, 4239, 4255,
    4287, 4319, 4347, 4377, 4404, 345, 4432, 4464, 4480, 4480, 4506, 4536,
    345, 4568, 4598, 4629, 4661, 345, 4688, 4714, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4743, 345, 4768, 4796, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4826, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 4852, 345, 345, 345, 4884, 345, 345, 345,
    3504, 4916, 4948, 345, 345, 4980, 5007, 5007, 5019, 5007, 5007, 5007,
    5007, 5007, 5007, 5017, 5039, 5071, 5103, 5135, 5164, 5193, 5225, 5164,
    5254, 5286, 5304, 5007, 5007, 4991, 5012, 5007, 5332, 5008, 5007, 5364,
    5007, 5007, 5007, 5007, 5008, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 345, 345, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5380, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    5007, 5402, 5007, 5427, 3409, 345, 345, 345, 345, 345, 345, 345, 345,
    5446, 1041, 345, 5463, 5493, 345, 345, 5508, 345, 345, 345, 345, 345,
    345, 345, 345, 5538, 5567, 345, 5592, 1711, 5616, 5644, 3518, 1041, 5670,
    5695, 5727, 1190, 5756, 5788, 345, 345, 5814, 5843, 5875, 5907, 5923,
    5955, 5987, 345, 345, 345, 345, 345, 345, 345, 6016, 6048, 6052, 6056,
    6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048,
    6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068,
    6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060,
    6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052,
    6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072,
    6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064,
    6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056,
    6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048,
    6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068,
    6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060,
    6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052,
    6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072,
    6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064,
    6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056,
    6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048,
    6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068,
    6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060,
    6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052,
    6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072,
    6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064,
    6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056,
    6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048,
    6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068,
    6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060,
    6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052,
    6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072,
    6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064,
    6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6072, 6048, 6052, 6056,
    6060, 6064, 6068, 6072, 6048, 6052, 6056, 6060, 6064, 6068, 6100, 6125,
    6136, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168,
    6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168,
    6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168,
    6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168,
    6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168, 6168,
    6168, 6168, 6168, 6168, 6168, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 5007, 5007, 5007, 5007,
    5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007, 5007,
    6200, 6231, 6263, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 6279, 345, 345, 345, 345, 345, 6311, 6343, 6375, 6403,
    6434, 345, 345, 345, 6446, 6478, 6510, 6540, 6572, 6589, 6621, 6652,
    6684, 345, 345, 345, 345, 345, 345, 345, 345, 3406, 345, 345, 345, 345,
    345, 345, 6714, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 2605, 345, 2620, 345, 345, 345, 345, 345, 345, 1041, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2613, 345, 345,
    345, 345, 345, 2605, 345, 345, 345, 345, 345, 345, 345, 6745, 6761, 6793,
    345, 345, 345, 345, 345, 345, 6817, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 6849, 6857, 6883, 1035, 3292, 6899, 3407, 6931, 3533,
    6957, 3405, 345, 3292, 6989, 7021, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 7047, 1041, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 7071, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    7091, 345, 7121, 345, 345, 345, 345, 345, 345, 7131, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7159, 7176,
    7207, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7239, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7266,
    7295, 7317, 345, 345, 345, 345, 7347, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 7365, 7379, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    7411, 7429, 4185, 7451, 7467, 345, 345, 345, 7499, 5012, 7522, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345
};

propval_t linebreak_prop_array[] = {
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_BA, EA_Z, GB_Control, SC_Unknown,
    LB_LF, EA_Z, GB_LF, SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown,
    LB_BK, EA_Z, GB_Control, SC_Unknown, LB_CR, EA_Z, GB_CR, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_SP, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_QU, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_QU, EA_Na, GB_Other, SC_Unknown,
    LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_HY, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_SY, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_IS, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_NL, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_ZA, GB_Control, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_GL, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_GL, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_SpacingMark, SC_Thai,
    LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA,
    EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Virama, SC_Thai, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_SpacingMark, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_BA, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_GL, EA_N,
    GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Virama, SC_Myanmar, LB_SA,
    EA_Z, GB_Virama, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend,
    SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV,
    EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N,
    GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_Z,
    GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_N,
    GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z,
    GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z,
    GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z,
    GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_N,
    GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA,
    EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer,
    LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_N, GB_SpacingMark,
    SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Virama, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N,
    GB_Other, SC_Tai_Le, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z, GB_Virama, SC_Tai_Tham,
    LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark,
    SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham,
    LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM,
    EA_Z, GB_Virama, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_ZW, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_BA, EA_A, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other,
    SC_Unknown, LB_B2, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_IN, EA_A, GB_Other, SC_Unknown, LB_IN, EA_A, GB_Other,
    SC_Unknown, LB_IN, EA_A, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other,
    SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown, LB_BK, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other,
    SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other,
    SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other,
    SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other,
    SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other,
    SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control,
    SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control,
    SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control,
    SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control,
    SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control,
    SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_H, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other,
    SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other,
    SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other,
    SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other,
    SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_B2, EA_N, GB_Other, SC_Unknown, LB_B2, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other,
    SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CM, EA_ZW, GB_Extend,
    SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_ZW, GB_Extend,
    SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_W, GB_Extend,
    SC_Unknown, LB_CM, EA_W, GB_Extend, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_ZW, GB_Extend,
    SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W,
    GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA,
    EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_H2,
    EA_W, GB_LV, SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W,
    GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H2, EA_W, GB_LV,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown,
    LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV,
    EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown,
    LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV,
    EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IS, EA_W,
    GB_Other, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IN, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_PR, EA_W, GB_Other, SC_Unknown, LB_PO, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_PO, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_OP, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_NS, EA_F,
    GB_Other, SC_Unknown, LB_NS, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_OP, EA_H,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_CL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Extend, SC_Unknown, LB_NS, EA_H,
    GB_Extend, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z,
    GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CB, EA_N,
    GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown
};

