/*
 * This file is automatically generated.  DON'T EDIT THIS FILE MANUALLY.
 */

#include "sombok_constants.h"
#include "sombok.h"
#define UNICODE_VERSION "6.0.0"
const char *linebreak_unicode_version = UNICODE_VERSION;

const char *linebreak_propvals_EA[] = {
    "Z", "Na", "N", "A", "W", "H", "F", "ZA", "ZW", NULL
};
const char *linebreak_propvals_GB[] = {
    "CR", "LF", "Control", "Extend", "Prepend", "SpacingMark", "L", "V", 
    "T", "LV", "LVT", "Other", "Virama", "OtherLetter", NULL
};
const char *linebreak_propvals_LB[] = {
    "BK", "CR", "LF", "NL", "SP", "OP", "CL", "QU", "GL", "NS", "EX", "SY", 
    "IS", "PR", "PO", "NU", "AL", "ID", "IN", "HY", "BA", "BB", "B2", "CB", 
    "ZW", "CM", "WJ", "H2", "H3", "JL", "JV", "JT", "CP", "SG", "AI", "SA", 
    "XX", NULL
};
const char *linebreak_propvals_SC[] = {
    "Common", "Inherited", "Unknown", "Han", "Hangul", "Thai", "Lao", 
    "Myanmar", "Khmer", "Tai_Le", "New_Tai_Lue", "Tai_Tham", "Tai_Viet", 
    NULL
};

#define M (LINEBREAK_ACTION_MANDATORY)
#define D (LINEBREAK_ACTION_DIRECT)
#define I (LINEBREAK_ACTION_INDIRECT)
#define P (LINEBREAK_ACTION_PROHIBITED)
#define r(cc) static propval_t rule_##cc[]
/* Note: Entries related to BK, CR, CM, LF, NL aren't used by break(). */
    /* BkCrLfNlSpOpClQuGlNsExSyIsPrPoNuAlIdInHyBaBbB2CbZwCmWjH2H3JlJvJtCp */
r(BK)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(CR)={M,M,P,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(LF)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(NL)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(SP)={P,P,P,P,P,D,P,D,D,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P};
r(OP)={P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P};
r(CL)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(QU)={P,P,P,P,P,P,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(GL)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(NS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(EX)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(SY)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(IS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(PR)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,I,D,I,I,D,D,D,P,D,P,I,I,I,I,I,P};
r(PO)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(NU)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,D,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(AL)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,I,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(ID)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(IN)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(HY)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(BA)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(BB)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,D,P,I,P,I,I,I,I,I,P};
r(B2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,P,D,P,D,P,D,D,D,D,D,P};
r(CB)={P,P,P,P,P,D,P,I,I,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P};
r(ZW)={P,P,P,P,P,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,P,D,D,D,D,D,D,D,D};
r(CM)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
r(WJ)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P};
r(H2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P};
r(H3)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P};
r(JL)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,I,I,I,I,D,P};
r(JV)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P};
r(JT)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P};
r(CP)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,I,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P};
#undef r
propval_t *linebreak_rules[] = {
    rule_BK, rule_CR, rule_LF, rule_NL, rule_SP, rule_OP, rule_CL, rule_QU, 
    rule_GL, rule_NS, rule_EX, rule_SY, rule_IS, rule_PR, rule_PO, rule_NU, 
    rule_AL, rule_ID, rule_IN, rule_HY, rule_BA, rule_BB, rule_B2, rule_CB, 
    rule_ZW, rule_CM, rule_WJ, rule_H2, rule_H3, rule_JL, rule_JV, rule_JT, 
    rule_CP
};

size_t linebreak_rulessiz = 33;

unsigned short linebreak_prop_index[] = {
    0, 32, 64, 94, 125, 157, 189, 219, 248, 276, 307, 333, 345, 345, 363,
    345, 345, 345, 392, 343, 345, 345, 420, 345, 452, 452, 469, 498, 529,
    559, 589, 345, 620, 636, 652, 345, 681, 345, 345, 345, 345, 345, 345,
    345, 704, 721, 753, 345, 785, 345, 817, 849, 345, 345, 866, 897, 923,
    941, 962, 345, 345, 988, 1020, 1041, 1067, 1095, 1109, 345, 345, 345,
    345, 345, 1141, 1147, 1178, 1208, 1239, 1243, 1274, 1304, 1335, 1339,
    1370, 1396, 1335, 1339, 1428, 1458, 1239, 1476, 1508, 1538, 1568, 1571,
    1603, 1629, 1660, 1664, 1695, 1538, 1725, 1729, 1761, 1538, 1725, 1571,
    1793, 1823, 1725, 345, 1849, 1881, 1912, 1928, 1960, 345, 1991, 2023,
    2055, 345, 2086, 2118, 345, 2150, 2182, 2207, 2239, 345, 2271, 2292,
    2324, 2355, 2385, 345, 345, 345, 2417, 2417, 2417, 2449, 2449, 2478,
    2486, 2492, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2524, 2556,
    345, 345, 345, 345, 2557, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2589, 345, 345, 2618,
    2632, 2653, 2676, 2676, 2708, 2720, 2750, 1020, 2780, 345, 345, 345, 345,
    1561, 345, 345, 345, 2812, 2840, 2858, 2890, 2910, 2941, 345, 2973, 3005,
    3016, 3048, 3080, 3112, 345, 345, 3144, 3156, 3186, 3217, 3249, 3280,
    345, 3306, 345, 3334, 3080, 3366, 345, 345, 3398, 3429, 345, 345, 345,
    345, 345, 345, 3461, 966, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 3493, 3525, 3557, 3588, 3620, 3652, 3684,
    941, 3476, 3713, 3744, 3757, 3789, 3815, 3841, 3867, 3892, 3924, 3955,
    3985, 4017, 4047, 4074, 345, 345, 4087, 4110, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 4142, 4142, 4142, 4142, 4164, 4142, 4142, 4196, 4212,
    4244, 4276, 4304, 4334, 4361, 345, 4389, 4421, 4437, 4437, 4463, 4493,
    345, 4525, 4555, 4586, 4618, 345, 4645, 4671, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4700, 345, 4725, 4753, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4783, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 4809, 345, 345, 345, 4841, 345, 345, 345,
    3461, 4873, 4905, 345, 345, 4937, 4964, 4964, 4976, 4964, 4964, 4964,
    4964, 4964, 4964, 4974, 4996, 5028, 5060, 5092, 5121, 5150, 5179, 5121,
    5208, 5240, 5258, 4964, 4964, 4948, 4969, 4964, 5286, 4965, 4964, 5318,
    4964, 4964, 4964, 4964, 4965, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 345, 345, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 5103, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 5337, 4964, 5362, 3366, 345, 345, 345, 345, 345, 345, 345, 345,
    5381, 1020, 345, 5398, 345, 345, 345, 5428, 345, 345, 345, 345, 345, 345,
    345, 345, 5458, 5487, 345, 5512, 1662, 5536, 5564, 3475, 1020, 5590,
    5615, 5647, 1141, 5676, 5708, 345, 345, 5734, 5763, 5795, 5827, 5843,
    5875, 345, 345, 345, 345, 345, 345, 345, 345, 5907, 5939, 5943, 5947,
    5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939,
    5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959,
    5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951,
    5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943,
    5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963,
    5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955,
    5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947,
    5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939,
    5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959,
    5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951,
    5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943,
    5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963,
    5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955,
    5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947,
    5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939,
    5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959,
    5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951,
    5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943,
    5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963,
    5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955,
    5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947,
    5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939,
    5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959,
    5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951,
    5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943,
    5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963,
    5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955,
    5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5963, 5939, 5943, 5947,
    5951, 5955, 5959, 5963, 5939, 5943, 5947, 5951, 5955, 5959, 5991, 6016,
    6027, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 4964,
    4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964, 4964,
    4964, 4964, 4964, 6055, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 6086, 345, 345, 345, 345, 345, 6118, 6150,
    6182, 6210, 6241, 345, 345, 345, 6253, 6285, 6317, 6347, 6379, 6396,
    6428, 6459, 6491, 345, 345, 345, 345, 345, 345, 345, 345, 3363, 345, 345,
    345, 345, 345, 345, 6056, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 2558, 345, 2573, 345, 345, 345, 345, 345, 345, 1020, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2566,
    345, 345, 345, 345, 345, 2558, 345, 345, 345, 345, 345, 345, 345, 6522,
    6538, 6570, 345, 345, 345, 345, 345, 345, 6594, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 6626, 6634, 6660, 1014, 3249, 6676, 3364, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 6708, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    6728, 345, 6758, 345, 345, 345, 345, 345, 345, 6768, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 6800, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 6827,
    6856, 6878, 345, 345, 345, 345, 6908, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 6926, 6940, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    6972, 6990, 4142, 7012, 7028, 345, 345, 345, 7060, 4969, 7083, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345
};

propval_t linebreak_prop_array[] = {
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_BA, EA_Z, GB_Control, SC_Unknown,
    LB_LF, EA_Z, GB_LF, SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown,
    LB_BK, EA_Z, GB_Control, SC_Unknown, LB_CR, EA_Z, GB_CR, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_SP, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_QU, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_QU, EA_Na, GB_Other, SC_Unknown,
    LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_HY, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_SY, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_IS, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_NL, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_ZA, GB_Control, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_GL, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_GL, EA_ZA, GB_Extend, SC_Unknown,
    LB_GL, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_SpacingMark, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_N,
    GB_SpacingMark, SC_Thai, LB_SA, EA_N, GB_SpacingMark, SC_Thai, LB_SA,
    EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Virama, SC_Thai, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Prepend, SC_Thai, LB_SA, EA_N, GB_Prepend, SC_Thai, LB_SA, EA_N,
    GB_Prepend, SC_Thai, LB_SA, EA_N, GB_Prepend, SC_Thai, LB_SA, EA_N,
    GB_Prepend, SC_Thai, LB_SA, EA_N, GB_SpacingMark, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_SpacingMark, SC_Lao,
    LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_SpacingMark, SC_Lao,
    LB_SA, EA_N, GB_SpacingMark, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao,
    LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA,
    EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Prepend, SC_Lao, LB_SA, EA_N, GB_Prepend,
    SC_Lao, LB_SA, EA_N, GB_Prepend, SC_Lao, LB_SA, EA_N, GB_Prepend, SC_Lao,
    LB_SA, EA_N, GB_Prepend, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown,
    LB_GL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_GL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown,
    LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_GL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend,
    SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Virama, SC_Myanmar, LB_SA,
    EA_Z, GB_Virama, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend,
    SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown,
    LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_Z, GB_Control, SC_Khmer, LB_SA, EA_Z, GB_Control,
    SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N,
    GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA,
    EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer,
    LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer,
    LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Virama,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Khmer, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_GL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_Z, GB_Virama, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark,
    SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham,
    LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark,
    SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_Z, GB_Extend, SC_Tai_Tham, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA,
    EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_ZW, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_BA,
    EA_A, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other, SC_Unknown, LB_B2,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_IN,
    EA_A, GB_Other, SC_Unknown, LB_IN, EA_A, GB_Other, SC_Unknown, LB_IN,
    EA_A, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other, SC_Unknown, LB_BK,
    EA_Z, GB_Control, SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_A, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_A, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_H, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_OP,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM,
    EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM,
    EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_CM,
    EA_ZW, GB_Extend, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_ZW, GB_Extend, SC_Unknown, LB_CM, EA_ZW, GB_Extend, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_SpacingMark, SC_Myanmar, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet,
    LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet,
    LB_SA, EA_N, GB_Prepend, SC_Tai_Viet, LB_SA, EA_N, GB_Prepend,
    SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Viet, LB_SA, EA_N, GB_Prepend, SC_Tai_Viet, LB_SA, EA_N, GB_Other,
    SC_Tai_Viet, LB_SA, EA_N, GB_Prepend, SC_Tai_Viet, LB_SA, EA_N,
    GB_Prepend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_H2, EA_W, GB_LV,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H2, EA_W, GB_LV,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown,
    LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV,
    EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown,
    LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV,
    EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_JV, EA_W, GB_V,
    SC_Unknown, LB_JV, EA_W, GB_V, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T,
    SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown,
    LB_JT, EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_JT,
    EA_W, GB_T, SC_Unknown, LB_JT, EA_W, GB_T, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_CM, EA_ZA, GB_Extend, SC_Unknown, LB_CM, EA_ZA,
    GB_Extend, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IS, EA_W,
    GB_Other, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IN, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_PR, EA_W, GB_Other, SC_Unknown, LB_PO, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_PO, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_OP, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_NS, EA_F,
    GB_Other, SC_Unknown, LB_NS, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_OP, EA_H,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_CL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_NS, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_NS, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_NS, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_NS, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_NS, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Extend, SC_Unknown, LB_NS, EA_H,
    GB_Extend, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z,
    GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CB, EA_N,
    GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown
};

